jaya: Jaya Algorithm, a gradient-free optimization algorithm.
Maximization of a function using Jaya Algorithm (JA).
A population based method which repeatedly modifies a population of individual solutions.
Capable of solving both constrained and unconstrained optimization problems.
Does not contain any hyperparameters.
Description
Jaya Algorithm, a gradient-free optimization algorithm.
Maximization of a function using Jaya Algorithm (JA).
A population based method which repeatedly modifies a population of individual solutions.
Capable of solving both constrained and unconstrained optimization problems.
Does not contain any hyperparameters.